Crate sup_xml_tree

Crate sup_xml_tree 

Tree types for the SupXML document model.

This crate defines the in-memory representation of an XML document — the libxml2-shaped arena DOM in dom. You rarely need to depend on this crate directly; everything is re-exported from the top-level sup-xml crate.

Unsafe policy

The dom module contains contained unsafe for the self-referential Document wrapper (the Document owns a Bump and the root pointer into that Bump). See dom module docs for the safety argument.

Re-exports

pub use dict::Dict;
pub use dom::HtmlDoctype;
pub use dom::HtmlMeta;
pub use dom::QuirksMode;
pub use dom::UnparsedEntity;

Modules

dict
Per-document string-interning dict with refcounted ownership.
dom
Bumpalo-backed, libxml2-shaped DOM.